AvrAtomic

Struct AvrAtomic 

pub struct AvrAtomic<T> { /* private fields */ }
A fast atomic type for 8-bit values on AVR microcontrollers.

This type has no IRQ-disable/restore or other locking overhead on AVR.

This type provides atomic load and store operations for u8, i8, and bool by default. But you can extend the supported types with your own types by implementing AvrAtomicConvert.

Internal implementation

Note that the internal representation of the data storage always is a u8, no matter that type T actually is.

Implementations

Source

impl<T> AvrAtomic<T>

pub const fn new() -> AvrAtomic<T>

Create a new AvrAtomic with the initial interior raw data being 0_u8.

pub fn load_raw(&self) -> u8

Atomically read as raw u8 byte.

This atomic read is also a full SeqCst memory barrier.

pub unsafe fn store_raw(&self, value: u8)

Atomically write as raw u8 byte.

This atomic write is also a full SeqCst memory barrier.

Safety

The caller must ensure that value is properly encoded to represent a valid T.

Source

impl<T: AvrAtomicConvert> AvrAtomic<T>

pub fn new_value(value: T) -> Self

Create a new AvrAtomic initialized to value.

pub fn load(&self) -> T

Atomically read the current value.

This atomic read is also a full SeqCst memory barrier.

pub fn store(&self, value: T)

Atomically write a new value.

This atomic write is also a full SeqCst memory barrier.