pub struct AvrAtomic<T> { /* private fields */ }Expand description
A fast atomic type for 8-bit values on AVR microcontrollers.
This type has no IRQ-disable/restore or other locking overhead on AVR.
This type provides atomic load and store operations for u8, i8, and bool
by default. But you can extend the supported types with your own types by
implementing AvrAtomicConvert.
Internal implementation
Note that the internal representation of the data storage always is a u8,
no matter that type T actually is.
Implementations
Sourceimpl<T> AvrAtomic<T>
impl<T> AvrAtomic<T>